# Japanese resource of comment_key.rb
#
# Copyright (c) 2005 Hahahaha <rin_ne@big.or.jp>
# Distributed under the GPL
#

@comment_key_label_conf = 'ȥե륿'

def comment_key_conf_html
	<<-"HTML"
		<h3 class="subtitle">#{@comment_key_label_conf}</h3>
		<p><input type="checkbox" name="comment_key_enable" value="true" #{'checked' if @conf['comment_key.enable']}>ȥե륿ͭˤ</p>
		<p>ȥե륿Τ˻Ѥ븰ƬʸꤷޤʤʸMD5ˤƥ󥳡ɤ뤿ᡢHTMLľɽ뤳ȤϤޤ</p>
		<p><input name="comment_key_prefix" value="#{h( @conf['comment_key.prefix'] || 'tdiary' )}" size="40"></p>
		<p><input type="checkbox" name="comment_key_nodate" value="true" #{'checked' if @conf['comment_key.nodate']}>Ʊθʸ</p>
	HTML
end
